==> com.liferay.batch.engine.service-4.0.28-sources-commercial.jar: com/liferay/batch/engine/internal/upgrade/BatchEngineServiceUpgrade.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.batch.engine.internal.upgrade;

import com.liferay.batch.engine.internal.upgrade.v4_0_0.VersionUpgradeProcess;
import com.liferay.batch.engine.internal.upgrade.v4_0_1.ClassNameUpgradeProcess;
import com.liferay.batch.engine.internal.upgrade.v4_1_0.TaskItemDelegateNameUpgradeProcess;
import com.liferay.batch.engine.internal.upgrade.v4_2_0.BatchEngineImportTaskUpgradeProcess;
import com.liferay.batch.engine.internal.upgrade.v4_3_0.BatchEngineExportTaskUpgradeProcess;
import com.liferay.batch.engine.internal.upgrade.v4_3_1.BatchEngineTaskUpgradeProcess;
import com.liferay.batch.engine.internal.upgrade.v4_5_0.BatchEngineImportTaskErrorUpgradeProcess;
import com.liferay.portal.kernel.module.framework.ModuleServiceLifecycle;
import com.liferay.portal.kernel.upgrade.DummyUpgradeStep;
import com.liferay.portal.upgrade.registry.UpgradeStepRegistrator;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Ivica Cardic
 */
@Component(immediate = true, service = UpgradeStepRegistrator.class)
public class BatchEngineServiceUpgrade implements UpgradeStepRegistrator {

	@Override
	public void register(Registry registry) {
		registry.register("2.0.0", "3.0.0", new DummyUpgradeStep());

		registry.register("3.0.0", "4.0.0", new VersionUpgradeProcess());

		registry.register("4.0.0", "4.0.1", new ClassNameUpgradeProcess());

		registry.register(
			"4.0.1", "4.1.0", new TaskItemDelegateNameUpgradeProcess());

		registry.register(
			"4.1.0", "4.2.0", new BatchEngineImportTaskUpgradeProcess());

		registry.register(
			"4.2.0", "4.3.0", new BatchEngineExportTaskUpgradeProcess());

		registry.register(
			"4.3.0", "4.3.1", new BatchEngineTaskUpgradeProcess());

		registry.register(
			"4.3.1", "4.4.0",
			new com.liferay.batch.engine.internal.upgrade.v4_4_0.
				BatchEngineExportTaskUpgradeProcess());

		registry.register(
			"4.4.0", "4.5.0", new BatchEngineImportTaskErrorUpgradeProcess(),
			new com.liferay.batch.engine.internal.upgrade.v4_5_0.
				BatchEngineImportTaskUpgradeProcess());
	}

	@Reference(target = ModuleServiceLifecycle.PORTAL_INITIALIZED)
	private ModuleServiceLifecycle _moduleServiceLifecycle;

}

==> com.liferay.batch.engine.service-4.0.40-sources-commercial.jar: com/liferay/batch/engine/internal/upgrade/BatchEngineServiceUpgrade.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.batch.engine.internal.upgrade;

import com.liferay.batch.engine.internal.upgrade.v4_0_0.VersionUpgradeProcess;
import com.liferay.batch.engine.internal.upgrade.v4_0_1.ClassNameUpgradeProcess;
import com.liferay.batch.engine.internal.upgrade.v4_1_0.TaskItemDelegateNameUpgradeProcess;
import com.liferay.batch.engine.internal.upgrade.v4_2_0.BatchEngineImportTaskUpgradeProcess;
import com.liferay.batch.engine.internal.upgrade.v4_3_0.BatchEngineExportTaskUpgradeProcess;
import com.liferay.batch.engine.internal.upgrade.v4_3_1.BatchEngineTaskUpgradeProcess;
import com.liferay.batch.engine.internal.upgrade.v4_5_0.util.BatchEngineImportTaskErrorTable;
import com.liferay.batch.engine.internal.upgrade.v4_6_1.BatchEngineTaskConfigurationUpgradeProcess;
import com.liferay.portal.kernel.module.configuration.ConfigurationProvider;
import com.liferay.portal.kernel.module.framework.ModuleServiceLifecycle;
import com.liferay.portal.kernel.service.CompanyLocalService;
import com.liferay.portal.kernel.upgrade.DummyUpgradeStep;
import com.liferay.portal.upgrade.registry.UpgradeStepRegistrator;

import org.osgi.service.cm.ConfigurationAdmin;
import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Ivica Cardic
 */
@Component(immediate = true, service = UpgradeStepRegistrator.class)
public class BatchEngineServiceUpgrade implements UpgradeStepRegistrator {

	@Override
	public void register(Registry registry) {
		registry.register("2.0.0", "3.0.0", new DummyUpgradeStep());

		registry.register("3.0.0", "4.0.0", new VersionUpgradeProcess());

		registry.register("4.0.0", "4.0.1", new ClassNameUpgradeProcess());

		registry.register(
			"4.0.1", "4.1.0", new TaskItemDelegateNameUpgradeProcess());

		registry.register(
			"4.1.0", "4.2.0", new BatchEngineImportTaskUpgradeProcess());

		registry.register(
			"4.2.0", "4.3.0", new BatchEngineExportTaskUpgradeProcess());

		registry.register(
			"4.3.0", "4.3.1", new BatchEngineTaskUpgradeProcess());

		registry.register(
			"4.3.1", "4.4.0",
			new com.liferay.batch.engine.internal.upgrade.v4_4_0.
				BatchEngineExportTaskUpgradeProcess());

		registry.register(
			"4.4.0", "4.5.0", BatchEngineImportTaskErrorTable.create(),
			new com.liferay.batch.engine.internal.upgrade.v4_5_0.
				BatchEngineImportTaskUpgradeProcess());

		registry.register(
			"4.5.0", "4.6.0",
			new com.liferay.batch.engine.internal.upgrade.v4_6_0.
				BatchEngineExportTaskUpgradeProcess(),
			new com.liferay.batch.engine.internal.upgrade.v4_6_0.
				BatchEngineImportTaskUpgradeProcess());

		registry.register(
			"4.6.0", "4.6.1",
			new BatchEngineTaskConfigurationUpgradeProcess(
				_companyLocalService, _configurationAdmin,
				_configurationProvider));
	}

	@Reference
	private CompanyLocalService _companyLocalService;

	@Reference
	private ConfigurationAdmin _configurationAdmin;

	@Reference
	private ConfigurationProvider _configurationProvider;

	@Reference(target = ModuleServiceLifecycle.PORTAL_INITIALIZED)
	private ModuleServiceLifecycle _moduleServiceLifecycle;

}
